@@ -1,7 +1,7 @@
 package App::lcpan;
 
-our $DATE = '2015-02-06'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2015-02-24'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -60,6 +60,9 @@ sub _set_args_default {
         require File::HomeDir;
         $args->{cpan} = File::HomeDir->my_home . '/cpan';
     }
+    if (!defined($args->{num_backups})) {
+        $args->{num_backups} = 7;
+    }
 }
 
 sub _fmt_time {
@@ -183,12 +186,17 @@ sub _create_schema {
         unless $res->[0] == 200;
 }
 
+sub _db_path {
+    my $cpan = shift;
+    "$cpan/index.db";
+}
+
 sub _connect_db {
     require DBI;
 
     my $cpan = shift;
 
-    my $db_path = "$cpan/index.db";
+    my $db_path = _db_path($cpan);
     $log->tracef("Connecting to SQLite database at %s ...", $db_path);
     my $dbh = DBI->connect("dbi:SQLite:dbname=$db_path", undef, undef,
                            {RaiseError=>1});
@@ -282,8 +290,6 @@ sub update_local_cpan_files {
     my $remote_url = $args{remote_url} // "http://mirrors.kernel.org/cpan";
     my $max_file_size = $args{max_file_size};
 
-    my $dbh = _connect_db($cpan);
-
     local $ENV{PERL5OPT} = "-MLWP::UserAgent::Patch::FilterMirrorMaxSize=-size,".($max_file_size+0).",-verbose,1"
         if defined $max_file_size;
 
@@ -294,6 +300,7 @@ sub update_local_cpan_files {
         @cmd,
     );
 
+    my $dbh = _connect_db($cpan);
     $dbh->do("INSERT OR REPLACE INTO meta (name,value) VALUES (?,?)",
              {}, 'last_mirror_time', time());
 
@@ -334,6 +341,16 @@ information.
 _
     args => {
         %common_args,
+        num_backups => {
+            summary => 'Keep a number of backups',
+            schema  => 'int*',
+            default => 7,
+            description => <<'_',
+
+Will create `index.db.1`, `index.db.2` and so on containing the older indexes.
+
+_
+        },
     },
 };
 sub update_local_cpan_index {
@@ -346,6 +363,21 @@ sub update_local_cpan_index {
     _set_args_default(\%args);
     my $cpan = $args{cpan};
 
+    my $db_path = _db_path($cpan);
+    if ($args{num_backups} > 0 && (-f $db_path)) {
+        require File::Copy;
+        require Logfile::Rotate;
+        $log->infof("Rotating old indexes ...");
+        my $rotate = Logfile::Rotate->new(
+            File  => $db_path,
+            Count => $args{num_backups},
+            Gzip  => 'no',
+        );
+        $rotate->rotate;
+        File::Copy::copy("$db_path.1", $db_path)
+              or return [500, "Copy $db_path.1 -> $db_path failed: $!"];
+    }
+
     my $dbh  = _connect_db($cpan);
 
     # parse 01mailrc.txt.gz and insert the parse result to 'author' table
@@ -656,9 +688,6 @@ sub update_local_cpan_index {
         $dbh->commit;
     }
 
-    $log->tracef("Disconnecting from SQLite database ...");
-    $dbh->disconnect;
-
     [200];
 }
 
@@ -1668,7 +1697,7 @@ App::lcpan - Manage your local CPAN mirror
 
 =head1 VERSION
 
-This document describes version 0.10 of App::lcpan (from Perl distribution App-lcpan), released on 2015-02-06.
+This document describes version 0.11 of App::lcpan (from Perl distribution App-lcpan), released on 2015-02-24.
 
 =head1 SYNOPSIS
 
@@ -1679,7 +1708,7 @@ See L<lcpan> script.
 
 =head2 authordists(%args) -> any
 
-{en_US List distributions of an author}.
+List distributions of an author.
 
 Arguments ('*' denotes required arguments):
 
@@ -1689,11 +1718,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<latest> => I<bool>
 
@@ -1704,7 +1731,7 @@ Return value:  (any)
 
 =head2 authormods(%args) -> any
 
-{en_US List modules of an author}.
+List modules of an author.
 
 Arguments ('*' denotes required arguments):
 
@@ -1714,11 +1741,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =back
 
@@ -1727,7 +1752,7 @@ Return value:  (any)
 
 =head2 authorrels(%args) -> any
 
-{en_US List releases of an author}.
+List releases of an author.
 
 Arguments ('*' denotes required arguments):
 
@@ -1737,11 +1762,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<full_path> => I<bool>
 
@@ -1754,7 +1777,7 @@ Return value:  (any)
 
 =head2 dist2rel(%args) -> any
 
-{en_US Get (latest) release name of a distribution}.
+Get (latest) release name of a distribution.
 
 Arguments ('*' denotes required arguments):
 
@@ -1762,11 +1785,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<dist>* => I<str>
 
@@ -1779,7 +1800,7 @@ Return value:  (any)
 
 =head2 distmods(%args) -> any
 
-{en_US List modules in a distribution}.
+List modules in a distribution.
 
 Arguments ('*' denotes required arguments):
 
@@ -1787,11 +1808,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<dist>* => I<str>
 
@@ -1802,7 +1821,7 @@ Return value:  (any)
 
 =head2 list_local_cpan_authors(%args) -> any
 
-{en_US List authors}.
+List authors.
 
 Examples:
 
@@ -1824,34 +1843,29 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<detail> => I<bool>
 
 =item * B<query> => I<str>
 
-{en_US Search query}.
+Search query.
 
 =back
 
 Return value:  (any)
 
 
-{en_US 
 By default will return an array of CPAN ID's. If you set C<detail> to true, will
 return array of records.
-}
 
 
 =head2 list_local_cpan_deps(%args) -> [status, msg, result, meta]
 
-{en_US List dependencies of a module, data from local CPAN}.
+List dependencies of a module, data from local CPAN.
 
-{en_US 
 By default only runtime requires are displayed. To see prereqs for other phases
 (e.g. configure, or build, or ALL) or for other relationships (e.g. recommends,
 or ALL), use the C<--phase> and C<--rel> options.
@@ -1863,7 +1877,6 @@ that requires running (untrusted) code.
 
 Also, some releases specify dynamic config, so there might actually be more
 dependencies.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -1871,25 +1884,23 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<include_core> => I<bool> (default: 0)
 
-{en_US Include Perl core modules}.
+Include Perl core modules.
 
 =item * B<level> => I<int> (default: 1)
 
-{en_US Recurse for a number of levels (-1 means unlimited)}.
+Recurse for a number of levels (-1 means unlimited).
 
 =item * B<module>* => I<str>
 
 =item * B<perl_version> => I<str> (default: "v5.18.4")
 
-{en_US Set base Perl version for determining core modules}.
+Set base Perl version for determining core modules.
 
 =item * B<phase> => I<str> (default: "runtime")
 
@@ -1911,7 +1922,7 @@ Return value:  (any)
 
 =head2 list_local_cpan_dists(%args) -> any
 
-{en_US List distributions}.
+List distributions.
 
 Examples:
 
@@ -1939,15 +1950,13 @@ Arguments ('*' denotes required arguments):
 
 =item * B<author> => I<str>
 
-{en_US Filter by author}.
+Filter by author.
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<detail> => I<bool>
 
@@ -1955,22 +1964,20 @@ Defaults to C<~/cpan>.
 
 =item * B<query> => I<str>
 
-{en_US Search query}.
+Search query.
 
 =back
 
 Return value:  (any)
 
 
-{en_US 
 By default will return an array of distribution names. If you set C<detail> to
 true, will return array of records.
-}
 
 
 =head2 list_local_cpan_modules(%args) -> any
 
-{en_US List packages/modules}.
+List packages/modules.
 
 Arguments ('*' denotes required arguments):
 
@@ -1978,40 +1985,36 @@ Arguments ('*' denotes required arguments):
 
 =item * B<author> => I<str>
 
-{en_US Filter by author}.
+Filter by author.
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<detail> => I<bool>
 
 =item * B<dist> => I<str>
 
-{en_US Filter by distribution}.
+Filter by distribution.
 
 =item * B<query> => I<str>
 
-{en_US Search query}.
+Search query.
 
 =back
 
 Return value:  (any)
 
 
-{en_US 
 By default will return an array of package names. If you set C<detail> to true,
 will return array of records.
-}
 
 
 =head2 list_local_cpan_packages(%args) -> any
 
-{en_US List packages/modules}.
+List packages/modules.
 
 Arguments ('*' denotes required arguments):
 
@@ -2019,40 +2022,36 @@ Arguments ('*' denotes required arguments):
 
 =item * B<author> => I<str>
 
-{en_US Filter by author}.
+Filter by author.
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<detail> => I<bool>
 
 =item * B<dist> => I<str>
 
-{en_US Filter by distribution}.
+Filter by distribution.
 
 =item * B<query> => I<str>
 
-{en_US Search query}.
+Search query.
 
 =back
 
 Return value:  (any)
 
 
-{en_US 
 By default will return an array of package names. If you set C<detail> to true,
 will return array of records.
-}
 
 
 =head2 list_local_cpan_releases(%args) -> any
 
-{en_US List releases/tarballs}.
+List releases/tarballs.
 
 Arguments ('*' denotes required arguments):
 
@@ -2060,15 +2059,13 @@ Arguments ('*' denotes required arguments):
 
 =item * B<author> => I<str>
 
-{en_US Filter by author}.
+Filter by author.
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<detail> => I<bool>
 
@@ -2086,7 +2083,7 @@ Defaults to C<~/cpan>.
 
 =item * B<query> => I<str>
 
-{en_US Search query}.
+Search query.
 
 =back
 
@@ -2095,7 +2092,7 @@ Return value:  (any)
 
 =head2 list_local_cpan_rev_deps(%args) -> [status, msg, result, meta]
 
-{en_US List reverse dependencies of a module, data from local CPAN}.
+List reverse dependencies of a module, data from local CPAN.
 
 Arguments ('*' denotes required arguments):
 
@@ -2103,29 +2100,23 @@ Arguments ('*' denotes required arguments):
 
 =item * B<author> => I<array[str]>
 
-{en_US Filter certain author}.
+Filter certain author.
 
-{en_US 
 This can be used to select certain author(s).
-}
 
 =item * B<author_isnt> => I<array[str]>
 
-{en_US Filter out certain author}.
+Filter out certain author.
 
-{en_US 
 This can be used to filter out certain author(s). For example if you want to
 know whether a module is being used by another CPAN author instead of just
 herself.
-}
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<module>* => I<str>
 
@@ -2145,7 +2136,7 @@ Return value:  (any)
 
 =head2 mod2dist(%args) -> any
 
-{en_US Get distribution name of a module}.
+Get distribution name of a module.
 
 Arguments ('*' denotes required arguments):
 
@@ -2153,11 +2144,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<module>* => I<str>
 
@@ -2168,7 +2157,7 @@ Return value:  (any)
 
 =head2 mod2rel(%args) -> any
 
-{en_US Get (latest) release name of a module}.
+Get (latest) release name of a module.
 
 Arguments ('*' denotes required arguments):
 
@@ -2176,11 +2165,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<full_path> => I<bool>
 
@@ -2193,7 +2180,7 @@ Return value:  (any)
 
 =head2 stat_local_cpan(%args) -> [status, msg, result, meta]
 
-{en_US Statistics of your local CPAN mirror}.
+Statistics of your local CPAN mirror.
 
 Arguments ('*' denotes required arguments):
 
@@ -2201,11 +2188,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =back
 
@@ -2223,11 +2208,9 @@ Return value:  (any)
 
 =head2 update_local_cpan(%args) -> [status, msg, result, meta]
 
-{en_US Update local CPAN mirror files, followed by create/update the index.db}.
+Update local CPAN mirror files, followed by create/update the index.db.
 
-{en_US 
 This subcommand calls the C<update-files> followed by C<update-index>.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -2235,11 +2218,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =back
 
@@ -2257,14 +2238,12 @@ Return value:  (any)
 
 =head2 update_local_cpan_files(%args) -> [status, msg, result, meta]
 
-{en_US Update local CPAN mirror files using minicpan command}.
+Update local CPAN mirror files using minicpan command.
 
-{en_US 
 This subcommand runs the C<minicpan> command to download/update your local CPAN
 mirror files.
 
 Note: you can also run C<minicpan> yourself.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -2272,19 +2251,17 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
 
 =item * B<max_file_size> => I<int>
 
-{en_US If set, skip downloading files larger than this}.
+If set, skip downloading files larger than this.
 
 =item * B<remote_url> => I<str>
 
-{en_US Select CPAN mirror to download from}.
+Select CPAN mirror to download from.
 
 =back
 
@@ -2302,9 +2279,8 @@ Return value:  (any)
 
 =head2 update_local_cpan_index(%args) -> [status, msg, result, meta]
 
-{en_US Create/update index.db in local CPAN mirror}.
+Create/update index.db in local CPAN mirror.
 
-{en_US 
 This subcommand is called by the C<update> subcommand after C<update-files> but
 can be performed separately via C<update-index>. Its task is to create/update
 C<index.db> SQLite database containing list of authors, modules, dists, and
@@ -2316,7 +2292,6 @@ It gets list of packages from parsing C<modules/02packages.details.txt.gz>.
 Afterwards, it tries to extract dist metadata C<META.yml> or C<META.json> from
 each release file to get distribution name, abstract, and dependencies
 information.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -2324,11 +2299,15 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<str>
 
-{en_US Location of your local CPAN mirror, e.g. /path/to/cpan}.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
-{en_US 
 Defaults to C<~/cpan>.
-}
+
+=item * B<num_backups> => I<int> (default: 7)
+
+Keep a number of backups.
+
+Will create C<index.db.1>, C<index.db.2> and so on containing the older indexes.
 
 =back
 
